Module binding

Module binding 

Computational binding property verification.

The binding property ensures that a commitment cannot be opened to two different values. We test this computationally by attempting to find alternative openings (which should fail for secure schemes).

Structs

BindingVerifier
Verifier for the binding property of commitments.