PedersenCommitment

Struct PedersenCommitment 

pub struct PedersenCommitment {
    pub point: RistrettoPoint,
    pub compressed: CompressedRistretto,
}
A Pedersen commitment.

Fields

point: RistrettoPoint

The commitment point C = rG + vH.

compressed: CompressedRistretto

The compressed (serialized) form.

Implementations

Source

impl PedersenCommitment

pub fn commit( params: &PedersenParams, value: &Scalar, ) -> (Self, PedersenOpening)

Commit to a value with a random blinding factor.

pub fn commit_with_randomness( params: &PedersenParams, value: &Scalar, randomness: &Scalar, ) -> Self

Commit to a value with a specific blinding factor.

pub fn verify( params: &PedersenParams, opening: &PedersenOpening, commitment: &PedersenCommitment, ) -> bool

Verify an opening against this commitment.

pub fn commit_u64( params: &PedersenParams, value: u64, ) -> (Self, PedersenOpening)

Create a commitment from a u64 value.

pub fn identity() -> Self

The identity (zero) commitment.

pub fn add(&self, other: &PedersenCommitment) -> PedersenCommitment

Add two commitments homomorphically: C1 + C2 commits to v1 + v2.