pub struct PedersenCommitment {
pub point: RistrettoPoint,
pub compressed: CompressedRistretto,
}Expand description
A Pedersen commitment.
Fields
point: RistrettoPointThe commitment point C = rG + vH.
compressed: CompressedRistrettoThe compressed (serialized) form.
Implementations
Sourceimpl PedersenCommitment
impl PedersenCommitment
Sourcepub fn commit(
params: &PedersenParams,
value: &Scalar,
) -> (Self, PedersenOpening)
pub fn commit( params: &PedersenParams, value: &Scalar, ) -> (Self, PedersenOpening)
Commit to a value with a random blinding factor.
Sourcepub fn commit_with_randomness(
params: &PedersenParams,
value: &Scalar,
randomness: &Scalar,
) -> Self
pub fn commit_with_randomness( params: &PedersenParams, value: &Scalar, randomness: &Scalar, ) -> Self
Commit to a value with a specific blinding factor.
Sourcepub fn verify(
params: &PedersenParams,
opening: &PedersenOpening,
commitment: &PedersenCommitment,
) -> bool
pub fn verify( params: &PedersenParams, opening: &PedersenOpening, commitment: &PedersenCommitment, ) -> bool
Verify an opening against this commitment.
Sourcepub fn commit_u64(
params: &PedersenParams,
value: u64,
) -> (Self, PedersenOpening)
pub fn commit_u64( params: &PedersenParams, value: u64, ) -> (Self, PedersenOpening)
Create a commitment from a u64 value.
Sourcepub fn add(&self, other: &PedersenCommitment) -> PedersenCommitment
pub fn add(&self, other: &PedersenCommitment) -> PedersenCommitment
Add two commitments homomorphically: C1 + C2 commits to v1 + v2.